@@ -31,6 +31,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 
 #include <gnuastro/wcs.h>
 #include <gnuastro/fits.h>
+#include <gnuastro-internal/checkset.h>
 
 #include "main.h"
 
@@ -79,7 +80,10 @@ operands_add(struct arithmeticparams *p, char *filename, gal_data_t *data)
       if(filename != NULL && gal_fits_name_is_fits(filename))
         {
           /* Set the HDU for this filename. */
-          newnode->hdu=gal_list_str_pop(&p->hdus);
+          if(p->globalhdu)
+            gal_checkset_allocate_copy(p->globalhdu, &newnode->hdu);
+          else
+            newnode->hdu=gal_list_str_pop(&p->hdus);
 
           /* Increment the FITS counter. */
           ++p->addcounter;
@@ -106,8 +110,8 @@ operands_pop(struct arithmeticparams *p, char *operator)
   /* If the operand linked list has finished, then give an error and
      exit. */
   if(operands==NULL)
-    error(EXIT_FAILURE, 0, "not enough operands for the \"%s\" "
-          "operator", operator);
+    error(EXIT_FAILURE, 0, "not enough operands for the \"%s\" operator",
+          operator);
 
 
   /* Set the dataset. If filename is present then read the file
@@ -117,13 +121,22 @@ operands_pop(struct arithmeticparams *p, char *operator)
       hdu=operands->hdu;
       filename=operands->filename;
 
-      /* In case this is the first image that is read, then read the WCS
-         information.*/
-      if(p->popcounter==0)
-        p->refdata.wcs=gal_wcs_read(filename, hdu, 0, 0, &p->refdata.nwcs);
+      /* Read the dataset. */
+      data=gal_fits_img_read(filename, hdu, p->cp.minmapsize, 0, 0);
 
-      /* Read the input image as a double type array. */
-      data=gal_fits_img_read(filename, hdu, p->cp.minmapsize);
+      /* In case this is the first image that is read, then keep the WCS
+         information in the `refdata' structure. Otherwise, the WCS is not
+         necessary and we can safely free it. In any case, `data' must not
+         have a WCS structure. */
+      if(p->popcounter==0)
+        {
+          p->refdata.wcs=data->wcs;
+          p->refdata.nwcs=data->nwcs;
+        }
+      else
+        wcsfree(data->wcs);
+      data->wcs=NULL;
+      data->nwcs=0;
 
       /* When the reference data structure's dimensionality is non-zero, it
          means that this is not the first image read. So, write its basic
