@@ -237,7 +237,7 @@ txt_info_from_comment(char *line, gal_data_t **datall, char *comm_start)
          are dealing with the string type, we have to pull out the number
          part first. If there is no number for a string type, then ignore
          the line. */
-      if(typestr)
+      if(typestr && *typestr!='\0')
         {
           typestr=txt_trim_space(typestr);
           if( !strncmp(typestr, "str", 3) )
@@ -296,11 +296,19 @@ txt_info_from_first_row(char *line, gal_data_t **datall, int format)
   size_t n=0, maxcnum=0, numtokens;
   char *token, *end=line+strlen(line);
 
-  /* Remove the new line character from the end of the line. If the last
-     column is a string, and the given length is larger than the available
-     space on the line, we don't want to have the line's new-line
-     character. Its better for it to actually be shorter than the space. */
-  *(end-1)='\0';
+  /* Remove the line termination character(s) from the end of the line. In
+     Unix, the line terminator is just the new-line character, however, in
+     some operating systems (like MS Windows), it is two characters:
+     carriage return and new-line. To be able to deal with both, we will be
+     checking the second last character first, the ASCII code for carriage
+     return is 13.
+
+     If the last column is a string, and the given length is larger than
+     the available space on the line, we don't want to have the line's
+     new-line character. Its better for it to actually be shorter than the
+     space. */
+  if( *(end-2)==13 ) *(end-2)='\0';
+  else               *(end-1)='\0';
 
   /* Get the maximum number of columns read from the comment
      information. */
@@ -768,8 +776,9 @@ txt_fill(char *line, char **tokens, size_t maxcolnum, gal_data_t *info,
   int notenoughcols=0;
   char *end=line+strlen(line);
 
-  /* See explanations in `txt_info_from_row'. */
-  *(end-1)='\0';
+  /* See explanations in `txt_info_from_first_row'. */
+  if( *(end-2)==13 ) *(end-2)='\0';
+  else               *(end-1)='\0';
 
   /* Start parsing the line. Note that `n' and `maxcolnum' start from
      one. */
@@ -781,7 +790,7 @@ txt_fill(char *line, char **tokens, size_t maxcolnum, gal_data_t *info,
       if(n>maxcolnum) break;
 
       /* Set the pointer to the start of this token/column. See
-         explanations in `txt_info_from_row'. */
+         explanations in `txt_info_from_first_row'. */
       if( info[n-1].type == GAL_TYPE_STRING )
         {
           /* Remove any delimiters and stop at the first non-delimiter. If
@@ -1134,8 +1143,7 @@ txt_print_value(FILE *fp, void *array, int type, size_t ind, char *fmt)
 
 static FILE *
 txt_open_file_write_info(gal_data_t *datall, char **fmts,
-                         gal_list_str_t *comment, char *filename,
-                         int dontdelete)
+                         gal_list_str_t *comment, char *filename)
 {
   FILE *fp;
   gal_data_t *data;
@@ -1144,9 +1152,13 @@ txt_open_file_write_info(gal_data_t *datall, char **fmts,
   gal_list_str_t *strt;
   int nlen, nw=0, uw=0, tw=0, bw=0;
 
+  /* Make sure the file doesn't already eixist. */
+  if( gal_checkset_check_file_return(filename) )
+    error(EXIT_FAILURE, 0, "%s: %s already exists. For safety, this "
+          "function will not over-write an existing file. Please delete "
+          "it before calling this function", __func__, filename);
 
-  /* Check the file and open it. */
-  gal_checkset_check_remove_file(filename, 0, dontdelete);
+  /* Open the output file. */
   errno=0;
   fp=fopen(filename, "w");
   if(fp==NULL)
@@ -1226,14 +1238,16 @@ txt_open_file_write_info(gal_data_t *datall, char **fmts,
 
 
 void
-gal_txt_write(gal_data_t *input, gal_list_str_t *comment, char *filename,
-              int dontdelete)
+gal_txt_write(gal_data_t *input, gal_list_str_t *comment, char *filename)
 {
   FILE *fp;
   char **fmts;
   size_t i, j, num=0, fmtlen;
   gal_data_t *data, *next2d=NULL;
 
+  /* Make sure input is valid. */
+  if(input==NULL) error(EXIT_FAILURE, 0, "%s: input is NULL", __func__);
+
 
   /* Currently only 1 and 2 dimension datasets are acceptable. */
   if( input->ndim!=1 && input->ndim!=2 )
@@ -1276,8 +1290,7 @@ gal_txt_write(gal_data_t *input, gal_list_str_t *comment, char *filename,
   /* Set the output FILE pointer: if it isn't NULL, its an actual file,
      otherwise, its the standard output. */
   fp = ( filename
-         ? txt_open_file_write_info(input, fmts, comment, filename,
-                                    dontdelete)
+         ? txt_open_file_write_info(input, fmts, comment, filename)
          : stdout );
 
 
